@@ -20,10 +20,6 @@ function GetCellValues(dataTable) {
     }
     var jsonString = JSON.stringify(Obj);
     document.getElementById('out').innerHTML = document.getElementById('out').innerHTML+jsonString;
-    //var XMLHttpRequestObj = FileResort.Utils.createRequest();
-    //XMLHttpRequestObj.open("POST", "/handle_table.pl", true);
-    //XMLHttpRequestObj.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
-    //XMLHttpRequestObj.send(requestData);
 }
 
 //--------------------------------------
@@ -100,8 +96,13 @@ function CloseAuth(el) {
   }
 }
 
-function HandleAuth() {
-  var el = event.target || event.srcElement;
+function HandleAuth(e) {
+  var el;
+  if (!e) {
+      el = event.target || event.srcElement;
+  } else {
+      el = e.target || e.srcElement;
+  }
   if (el.tagName == "INPUT") {
     // save or cancel button
     CloseAuth(el);
